.. image:: masthead.svg
   :align: center

.. title:: glooey — An object-oriented GUI library for pyglet

.. include:: ../README.rst
   :start-line: 4
   :end-before: A quick example

.. toctree::
    :caption: Tutorials
    :hidden:

    installation
    getting_started
    especially_useful_widgets
    stylizing_widgets
    padding_alignment_size_hints
    more_useful_widgets
    mouse_and_keyboard_input
    composing_widgets
    how_it_all_works
    making_widgets_from_scratch
    troubleshooting

.. autosummary::
    :caption: API Reference
    :toctree: api
    :recursive:

    glooey.widget
    glooey.root
    glooey.containers
    glooey.buttons
    glooey.images
    glooey.text
    glooey.scrolling
    glooey.dialogs
    glooey.misc
    glooey.drawing
    glooey.helpers
    glooey.themes
